==> HostCMS-6.1.7.tar: modules/module/i18n/ru.php <==
<?php
/**
 * Modules.
 *
 * @package HostCMS 6\Module
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2013 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Модули',
	'menu' => 'Модули',
	'tab_attribute' => 'Параметры',
	'tab_parameters' => 'Настройки модуля',
	'modules_add_success' => 'Модуль успешно добавлен!',
	'edit_success' => 'Модуль успешно изменен!',
	'modules_add_error_path1' => 'Ошибка! Модуль с таким путем уже существует в базе.',
	'modules_add_error_path2' => 'Ошибка! Путь для модуля не может быть пустым.',
	'modules_add_error_path3' => 'Ошибка создания директории модуля! Возможно Вы указали некорректнный путь к директории модуля.',
	'modules_add_error_create_module_file' => 'Ошибка! Файл модуля не создан!',
	'modules_add_error_create_config_dir' => 'Ошибка! Каталог для файла параметров модуля не создан!',
	'markDeleted_success' => 'Модуль успешно удален!',
	'modules_deletes_message' => 'Модули успешно удалены!',
	'apply_success' => 'Информация изменена!',
	'changeActive_success' => 'Статус изменен!',
	'changeIndexing_success' => 'Индексация изменена!',
	'modules_add_form_title' => 'Добавление информации о модуле',
	'modules_edit_form_title' => 'Редактирование информации о модуле',
	'modules_show_modules_link' => 'Список модулей',
	'id' => 'Идентификатор',
	'name' => '<acronym title="Название модуля">Название модуля</acronym>',
	'description' => '<acronym title="Дополнительная информация о модуле">Описание модуля</acronym>',
	'modules_add_form_params' => '<acronym title="PHP-код с параметрами модуля. Вызывается перед инициализацией модуля">PHP-код с параметрами модуля</acronym>',
	'modules_add_form_status' => '<acronym title="Флаг активности модуля. Выключенные модули не инициализируются">Статус</acronym>',
	'active' => 'Активен',
	'indexing' => 'Индексировать',
	'path' => '<acronym title="Название директории размещения модуля. Модули размещаются в [Корневая директория] / modules / [имя модуля]">Путь к модулю</acronym>',
	'sorting' => '<acronym title="Поле, по которому производится сортировка модуля при инициализации">Порядок сортировки</acronym>',
	'modules_title' => 'Модуль',
	'modules_title_list' => 'Список модулей',
	'modules_add_link' => 'Добавить',
	'error_file_open' => 'Невозможно открыть файл ',
	'error_file_write' => 'Невозможно записать в файл ',
	'modules_active_set' => 'Активность модуля "%s" установлена',
	'modules_active_unset' => 'Активность модуля "%s" снята',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);

==> HostCMS-6.8.6.tar: modules/module/i18n/ru.php <==
<?php
/**
 * Modules.
 *
 * @package HostCMS
 * @subpackage Module
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Модули',
	'menu' => 'Модули',
	'tab_attribute' => 'Параметры',
	'tab_parameters' => 'Настройки модуля',
	'modules_add_success' => 'Модуль успешно добавлен!',
	'edit_success' => 'Модуль успешно изменен!',
	'modules_add_error_path1' => 'Ошибка! Модуль с таким путем уже существует в базе.',
	'modules_add_error_path2' => 'Ошибка! Путь для модуля не может быть пустым.',
	'modules_add_error_path3' => 'Ошибка создания директории модуля! Возможно Вы указали некорректнный путь к директории модуля.',
	'modules_add_error_create_module_file' => 'Ошибка! Файл модуля не создан!',
	'modules_add_error_create_config_dir' => 'Ошибка! Каталог для файла параметров модуля не создан!',
	'markDeleted_success' => 'Модуль успешно удален!',
	'modules_deletes_message' => 'Модули успешно удалены!',
	'apply_success' => 'Информация изменена!',
	'changeActive_success' => 'Статус изменен!',
	'changeIndexing_success' => 'Индексация изменена!',
	'modules_add_form_title' => 'Добавление информации о модуле',
	'modules_edit_form_title' => 'Редактирование информации о модуле "%s"',
	'modules_show_modules_link' => 'Список модулей',
	'id' => 'Идентификатор',
	'name' => 'Название модуля',
	'description' => 'Описание модуля',
	'modules_add_form_params' => '<acronym title="PHP-код с параметрами модуля. Вызывается перед инициализацией модуля">PHP-код с параметрами модуля</acronym>',
	'active' => 'Активен',
	'indexing' => 'Индексировать',
	'path' => '<acronym title="Название директории размещения модуля. Модули размещаются в [Корневая директория] / modules / [имя модуля]">Путь к модулю</acronym>',
	'sorting' => '<acronym title="Поле, по которому производится сортировка модуля при инициализации">Порядок сортировки</acronym>',
	'modules_title' => 'Модуль',
	'modules_title_list' => 'Список модулей',
	'modules_add_link' => 'Добавить',
	'error_file_open' => 'Невозможно открыть файл ',
	'error_file_write' => 'Невозможно записать в файл ',
	'modules_active_set' => 'Активность модуля "%s" установлена',
	'modules_active_unset' => 'Активность модуля "%s" снята',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);
